@@ -202,6 +202,16 @@ impl_GetChildren (DBusConnection *bus,
   g_return_val_if_fail (ATK_IS_OBJECT (user_data),
                         droute_not_yet_handled_error (message));
   count = atk_object_get_n_accessible_children (object);
+
+  if (count > ATSPI_MAX_CHILDREN)
+    {
+      gchar *errmsg = g_strdup_printf (
+          "Accessible's child count %d exceeds the maximum of %d handled by GetChildren.", count, ATSPI_MAX_CHILDREN);
+      reply = dbus_message_new_error (message, DBUS_ERROR_INVALID_ARGS, errmsg);
+      g_free (errmsg);
+      return reply;
+    }
+
   reply = dbus_message_new_method_return (message);
   if (!reply)
     goto oom;
