@@ -513,11 +513,12 @@ get_plug_id (AtkPlug *plug)
 {
   const char *uname;
   gchar *path;
-  GString *str = g_string_new (NULL);
+  GString *str;
 
   if (!spi_global_app_data || !spi_global_app_data->bus)
     return NULL;
 
+  str = g_string_new (NULL);
   uname = dbus_bus_get_unique_name (spi_global_app_data->bus);
   path = spi_register_object_to_path (spi_global_register, G_OBJECT (plug));
   g_string_printf (str, "%s:%s", uname, path);
@@ -1264,6 +1265,8 @@ atk_bridge_adaptor_init (gint *argc, gchar **argv[])
       g_free (spi_global_app_data->desktop_name);
       g_free (spi_global_app_data->desktop_path);
       droute_free (spi_global_app_data->droute);
+      if (spi_global_app_data->property_hash)
+        g_hash_table_destroy (spi_global_app_data->property_hash);
       g_free (spi_global_app_data);
       spi_global_app_data = NULL;
       inited = FALSE;
@@ -1348,6 +1351,9 @@ atk_bridge_adaptor_cleanup (void)
 
   g_clear_object (&spi_global_app_data->session_bus);
 
+  if (spi_global_app_data->property_hash)
+    g_hash_table_destroy (spi_global_app_data->property_hash);
+
   g_free (spi_global_app_data);
   spi_global_app_data = NULL;
 
