@@ -23,8 +23,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef _ATSPI_MISC_H_
-#define _ATSPI_MISC_H_
+#pragma once
 
 G_BEGIN_DECLS
 
@@ -49,6 +48,6 @@ atspi_set_main_context (GMainContext *cnx);
 gchar *atspi_role_get_name (AtspiRole role);
 
 gchar *atspi_role_get_localized_name (AtspiRole role);
-G_END_DECLS
 
-#endif /* _ATSPI_MISC_H_ */
+void atspi_get_version (gint *major, gint *minor, gint *micro);
+G_END_DECLS
